PaginatedData<T> class abstract

Contract that any paginated response should implement so the UI layer can work with it generically.

Constructors

PaginatedData()

Properties

hashCode int
The hash code for this object.
no setterinherited
hasMore bool
no setter
items List<T>
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited